@@ -3,14 +3,10 @@ import sys
 import logging
 
 
-console = logging.StreamHandler(sys.stdout)
-formatter = logging.Formatter("[%(levelname)s] %(message)s")
-console.setFormatter(formatter)
-
 logger = logging.getLogger("deck")
-logger.addHandler(console)
 
-__VERSION__ = "0.9.3"
+
+__VERSION__ = "0.11.1"
 
 DECKFILE_FILE = "deck.yaml"
 
