@@ -1,10 +1,9 @@
 import logging
 from abc import ABC, abstractmethod
-from typing import List, Dict, Union
+from typing import List, Dict, Optional, Union
 
 from pydantic import BaseModel
 
-from getdeck.configuration import ClientConfiguration
 from getdeck.deckfile.errors import DeckfileError
 from getdeck.provider.abstract import AbstractProvider
 
@@ -17,7 +16,7 @@ class DeckfileCluster(BaseModel):
     name: str
     nativeConfig: dict = None
 
-    def get_provider(self, config: ClientConfiguration) -> AbstractProvider:
+    def get_provider(self, config) -> AbstractProvider:
         from getdeck.provider.factory import cluster_factory
         from getdeck.provider.types import ProviderType
 
@@ -35,10 +34,22 @@ class DeckfileCluster(BaseModel):
             raise e
 
 
-class DeckfileHelmSource(BaseModel):
+class InlineSource(BaseModel):
+    type: str = "inline"
+    content: Dict = None
+
+
+class FileSource(BaseModel):
+    type: str = "file"
+    ref: str = None
+    targetRevision: Optional[str] = None
+    path: str = ""
+
+
+class HelmSource(BaseModel):
     type: str = "helm"
     ref: str
-    targetRevision: str = ""
+    targetRevision: Optional[str] = None
     namespace: str = ""
     path: str = None
     chart: str = None  # this is set when pulling directly from a Helm repo
@@ -49,25 +60,17 @@ class DeckfileHelmSource(BaseModel):
     helmPlugins: List[str] = None
 
 
-class DeckfileFileSource(BaseModel):
-    type: str = "file"
-    ref: str = None
-    content: Dict = None
-    targetRevision: str = ""
-    path: str = ""
-
-
-class DeckfileKustomizeSource(BaseModel):
+class KustomizeSource(BaseModel):
     type: str = "kustomize"
     ref: str
-    targetRevision: str = ""
+    targetRevision: Optional[str] = None
     path: str = ""
 
 
-class DeckfileDirectorySource(BaseModel):
+class DirectorySource(BaseModel):
     type: str = "directory"
     ref: str
-    targetRevision: str = ""
+    targetRevision: Optional[str] = None
     path: str
     recursive: bool
 
@@ -79,10 +82,11 @@ class DeckfileDeck(BaseModel):
     hosts: List[str] = []
     sources: List[
         Union[
-            DeckfileHelmSource,
-            DeckfileDirectorySource,
-            DeckfileFileSource,
-            DeckfileKustomizeSource,
+            InlineSource,
+            FileSource,
+            DirectorySource,
+            HelmSource,
+            KustomizeSource,
         ]
     ]
 
@@ -93,14 +97,23 @@ class DeckfileDeck(BaseModel):
         if tsources:
             try:
                 for source in tsources:
-                    if source["type"].lower() == "helm":
-                        self.sources.append(DeckfileHelmSource(**source))
-                    elif source["type"].lower() == "file":
-                        self.sources.append(DeckfileFileSource(**source))
-                    elif source["type"].lower() == "directory":
-                        self.sources.append(DeckfileDirectorySource(**source))
-                    elif source["type"].lower() == "kustomize":
-                        self.sources.append(DeckfileKustomizeSource(**source))
+                    # inline deprecated warning
+                    source_type = source["type"].lower()
+                    if source_type == "file" and source.get("content", None):
+                        logger.warning(
+                            "'type: file' is deprecated for inline sources, "
+                            "use 'type: inline' instead",
+                        )
+                        source_type = "inline"
+
+                    source_class = {
+                        "inline": InlineSource,
+                        "file": FileSource,
+                        "directory": DirectorySource,
+                        "kustomize": KustomizeSource,
+                        "helm": HelmSource,
+                    }.get(source_type)
+                    self.sources.append(source_class(**source))
             except KeyError:
                 raise DeckfileError(
                     f"A source from Deck {data.get('name')} did not specify the 'type' argument."
