@@ -16,17 +16,6 @@ def _call_and_log(config, api, verb, obj, namespace, **kwargs):
         )
 
 
-def _delete_and_create(config, api, obj, namespace, **kwargs):
-    logger.debug(
-        f"Kubernetes: replacing {k8s_describe_object(obj)} "
-        f"failed. Attempting deletion and recreation."
-    )
-    k8s_call_api(config, api, "delete", obj, namespace, **kwargs)
-    if api:
-        logger.debug(f"Kubernetes: {k8s_describe_object(obj)} deleted")
-    _call_and_log(config, api, "create", obj, namespace, **kwargs)
-
-
 def create_namespace(config, name: str) -> None:
     from kubernetes.client.rest import ApiException
     from kubernetes.client import V1Namespace, V1ObjectMeta
@@ -57,13 +46,17 @@ def k8s_create_or_patch(
             _call_and_log(config, api, "create", obj, namespace, **kwargs)
             break
         except ApiException as e:
-            if e.reason in ["Not Found", "Internal Server Error"]:
+            if e.reason in ["Internal Server Error", "Unprocessable Entity"]:
+                continue
+            if e.reason == "Not Found":
                 logger.debug(e)
                 try:
                     # try to create this object as non-namespaced object
                     k8s_call_api(config, api, "create", obj, None, **kwargs)
                     break
                 except ApiException as ie:
+                    if ie.reason == "Conflict":
+                        break
                     logger.debug(ie)
                 if i < config.K8S_OBJECT_RETRY - 1:
                     logger.debug(
@@ -83,15 +76,6 @@ def k8s_create_or_patch(
                             f"Error installing object {obj['metadata']['name']}: {e.reason}"
                         )
                         raise RuntimeError(e)
-                    try:
-                        # try to delete this object and recreate it
-                        _delete_and_create(config, api, obj, namespace)
-                        break
-                    except Exception as ex:
-                        logger.error(
-                            f"Kubernetes: failure updating {k8s_describe_object(obj)}: {ex}"
-                        )
-                        raise RuntimeError(ex)
                 except ValueError as e:
                     logger.debug(
                         f"Error installing object {obj['metadata']['name']}: {e}. "
