@@ -6,17 +6,26 @@ from typing import List
 
 import yaml
 
-from getdeck.sources.tooler import ToolerFetcher
+from getdeck.sources.tooler import Tooler
 from getdeck.sources.types import K8sSourceFile
 
 logger = logging.getLogger("deck")
 
 
-class HelmFetcher(ToolerFetcher):
+class Helm(Tooler):
     @property
     def not_supported_message(self):
         return "This helm source is currently not supported"
 
+    @property
+    def type(self) -> str:
+        from getdeck.sources.utils import sniff_protocol
+
+        if self.source.ref is None:
+            raise RuntimeError("`source.ref` not specified")
+        protocol = sniff_protocol(self.source.ref)
+        return protocol
+
     def build_command(self) -> List[str]:
         helm_cmd = self._helm_prep()
         helm_cmd.append("&&")
@@ -51,14 +60,18 @@ class HelmFetcher(ToolerFetcher):
 
     @cached_property
     def k8s_api_version(self) -> str:
+        import re
+
         req = self.config.K8S_CORE_API.api_client.request(
             "GET", f"{self.config.K8S_CORE_API.api_client.configuration.host}/version"
         )
+        logger.debug(self.config.K8S_CORE_API.api_client.configuration.host)
         data = json.loads(req.data)
-        return f"{data['major']}.{data['minor']}"
+        logger.debug("Kube API version: " + str(data))
+        return f"{re.sub(r'[^0-9]+', '', data['major'])}.{re.sub(r'[^0-9]+', '', data['minor'])}"
 
     def _helm_prep(self) -> List[str]:
-        if self.type == "git":
+        if self.type in ["git", "local"]:
             return self._helm_dep_up()
         else:  # http(s)
             return self._helm_repo_add()
@@ -67,6 +80,8 @@ class HelmFetcher(ToolerFetcher):
         return ["helm", "repo", "add", "this", self.source.ref]
 
     def _helm_dep_up(self) -> List[str]:
+        if self.type == "local":
+            return ["helm", "dep", "up", self.source.ref]
         return ["helm", "dep", "up", self.source.path]
 
     def _helm_with_plugins(self) -> List[str]:
@@ -88,6 +103,29 @@ class HelmFetcher(ToolerFetcher):
                         ["--values", os.path.join(self.source.path, _valuefile)]
                     )
             return temp
+        elif self.type == "local":
+            temp = [
+                "template",
+                f"{self.source.releaseName}",
+                f"/sources/{self.source.ref.removeprefix('./')}",
+                "--include-crds",
+                "--namespace",
+                self.namespace,
+            ]
+            if self.source.valueFiles:
+                for _valuefile in self.source.valueFiles:
+                    temp.extend(
+                        [
+                            "--values",
+                            os.path.join(
+                                "/sources",
+                                self.source.ref.removeprefix("./"),
+                                self.source.path or "",
+                                _valuefile.removeprefix("./"),
+                            ),
+                        ]
+                    )
+            return temp
         else:  # http(s)
             return [
                 "template",
