@@ -1,17 +1,18 @@
+from abc import abstractmethod
 import io
 import logging
 import os
+import shutil
 import subprocess
 import sys
 import tempfile
 from functools import cached_property
 from typing import List, Union
 
-from git import Repo
-
 from getdeck.configuration import ClientConfiguration
+from getdeck.fetch.types import DeckfileAux, SourceAux
 from getdeck.sources import tooler
-from getdeck.sources.file import FileFetcher
+from getdeck.sources.generator import RenderBehavior
 from getdeck.sources.types import K8sSourceFile
 
 logger = logging.getLogger("deck")
@@ -76,8 +77,8 @@ def gnupg_agent_socket_path() -> str:
 def build_user_container(config: ClientConfiguration):
     logger.info("Building a local Tooler image for source generation")
     if sys.platform != "win32":
-        uid = os.getuid()
-        gid = os.getgid()
+        uid = os.getuid() or 1000
+        gid = os.getgid() or 1000
     else:
         uid = 1000
         gid = 1000
@@ -85,7 +86,10 @@ def build_user_container(config: ClientConfiguration):
     if sys.platform in ["darwin", "win32"]:
         user_group_add = "RUN addgroup -S tooler && adduser -S tooler -G tooler"
     else:
-        user_group_add = "RUN addgroup -g ${GROUP_ID} -S tooler && adduser -u ${USER_ID} -S tooler -G tooler"
+        user_group_add = (
+            "RUN getent group ${GROUP_ID} || addgroup -g ${GROUP_ID} -S tooler && "
+            "getent passwd ${USER_ID} || adduser -u ${USER_ID} -S tooler -G $(getent group ${GROUP_ID} | cut -d: -f1)"
+        )
 
     Dockerfile = io.BytesIO(
         (
@@ -113,38 +117,39 @@ def build_user_container(config: ClientConfiguration):
     )
 
 
-class ToolerFetcher(FileFetcher):
+class Tooler(RenderBehavior):
     SOURCES = "/sources"
     OUTPUT = "/output"
 
-    def fetch_content(self, **kwargs) -> List[K8sSourceFile]:
-        raise NotImplementedError
-
-    def fetch_local(self, **kwargs):
-        raise NotImplementedError
-
-    def fetch_remote(self, git=False):
+    def render(self, deckfile_aux: DeckfileAux, source_aux: SourceAux, **kwargs):
         cmd = self.build_command()
         try:
-            if git:
-                self._checkout_git()
+            if source_aux.temporary_data:
+                source_path = source_aux.temporary_data.data
+            else:
+                source_path = source_aux.path
+
+            if source_path:
+                if not os.path.isabs(source_path):
+                    source_path = os.path.join(
+                        deckfile_aux.path, source_path.removeprefix("./")
+                    )
+
+                # copy data
+                if os.path.isdir(source_path):
+                    shutil.copytree(
+                        source_path, self.tmp_source.name, dirs_exist_ok=True
+                    )
+                else:
+                    shutil.copy(source_path, self.tmp_source.name)
+
+            logger.debug(f"Render: {source_aux.location}")
             self.run_tooler(cmd)
-            return self.collect_workload_files()
+            source_files = self.collect_workload_files()
+            return source_files
         finally:
             self.cleanup()
 
-    def fetch_http(self, **kwargs) -> List[K8sSourceFile]:
-        return self.fetch_remote(git=False)
-
-    def fetch_git(self, **kwargs) -> List[K8sSourceFile]:
-        return self.fetch_remote(git=True)
-
-    def _checkout_git(self):
-        logger.debug(f"Cloning from {self.source.ref} to {self.tmp_source.name}")
-        repo = Repo.clone_from(self.source.ref, self.tmp_source.name)
-        if self.source.targetRevision:
-            repo.git.checkout(self.source.targetRevision)
-
     @cached_property
     def tmp_output(self):
         return tempfile.TemporaryDirectory()
@@ -157,6 +162,7 @@ class ToolerFetcher(FileFetcher):
         self.tmp_output.cleanup()
         self.tmp_source.cleanup()
 
+    @abstractmethod
     def build_command(self) -> List[str]:
         raise NotImplementedError
 
@@ -170,5 +176,6 @@ class ToolerFetcher(FileFetcher):
             ],
         )
 
-    def collect_workload_files(self):
+    @abstractmethod
+    def collect_workload_files(self) -> List[K8sSourceFile]:
         raise NotImplementedError
