@@ -1,102 +1,26 @@
 import logging
 import os
 import subprocess
-import tempfile
 from time import sleep
 
-import requests
-from git import Repo, GitError
 from semantic_version import Version
 
-from getdeck import configuration
 from getdeck.configuration import ClientConfiguration
 from getdeck.deckfile.file import Deckfile
 from getdeck.provider.abstract import AbstractProvider
 from getdeck.provider.errors import NotSupportedError
 from getdeck.provider.types import ProviderType
 
+
 logger = logging.getLogger("deck")
 
 
-def sniff_protocol(ref: str):
-    if "#" in ref:
-        ref, rev = ref.split("#")
-    ref_lo = ref.lower()
-    if ref_lo.startswith("git") or ref_lo.endswith(".git"):
-        return "git"
-    if ref_lo.startswith("https"):
-        return "https"
-    if ref_lo.startswith("http"):
-        return "http"
-    if ref_lo[0] in "./~":
-        return "local"
-    return None
-
-
-def read_deckfile_from_location(location: str, config: ClientConfiguration) -> Deckfile:
-    protocol = sniff_protocol(location)
-    if location == ".":
-        # load default file from this location
-        return config.deckfile_selector.get(
-            os.path.join(os.getcwd(), configuration.DECKFILE_FILE)
-        )
-    elif protocol == "git":
-        if "#" in location:
-            ref, rev = location.split("#")
-        else:
-            ref = location
-            rev = "HEAD"
-        tmp_dir = tempfile.TemporaryDirectory()
-        try:
-            repo = Repo.clone_from(ref, tmp_dir.name)
-            repo.git.checkout(rev)
-            deckfile = config.deckfile_selector.get(
-                os.path.join(tmp_dir.name, configuration.DECKFILE_FILE)
-            )
-            tmp_dir.cleanup()
-            return deckfile
-        except GitError as e:
-            tmp_dir.cleanup()
-            raise RuntimeError(f"Cannot checkout {rev} from {ref}: {e}")
-        except Exception as e:
-            tmp_dir.cleanup()
-            raise e
-    elif protocol in ["http", "https"]:
-        download = tempfile.NamedTemporaryFile(delete=False)
-        try:
-            logger.debug(f"Requesting {location}")
-            with requests.get(location, stream=True, timeout=10.0) as res:
-                res.raise_for_status()
-                for chunk in res.iter_content(chunk_size=4096):
-                    if chunk:
-                        download.write(chunk)
-                download.flush()
-            download.close()
-            deckfile = config.deckfile_selector.get(download.name)
-            os.remove(download.name)
-            return deckfile
-        except Exception as e:
-            download.close()
-            os.remove(download.name)
-            raise RuntimeError(
-                f"Cannot read Deckfile from http(s) location {location}: {e}"
-            )
-    elif protocol in (None, "local"):
-        # this is probably a file system location
-        if os.path.isfile(location):
-            logger.debug("Is file location")
-            return config.deckfile_selector.get(location)
-        else:
-            raise RuntimeError(f"Cannot identify {location} as Deckfile")
-    else:
-        raise RuntimeError("Cannot read Deckfile")
-
-
 def ensure_cluster(
     deckfile: Deckfile,
     config: ClientConfiguration,
     ignore_cluster: bool = False,
     do_install: bool = True,
+    no_input: bool = False,
 ) -> AbstractProvider:
     from kubernetes.client.rest import ApiException
     from getdeck.provider.factory import cluster_factory
@@ -145,12 +69,13 @@ def ensure_cluster(
                             f"but minVersion is {cluster_config.minVersion}"
                         )
                         if do_install:
-                            confirm = input(
-                                f"Do you want to update your local {cluster_config.provider}? [y/N] "
-                            )
-                            if confirm.lower() != "y":
-                                logger.info("Operation aborted")
-                                exit()
+                            if not no_input:
+                                confirm = input(
+                                    f"Do you want to update your local {cluster_config.provider}? [y/N] "
+                                )
+                                if confirm.lower() != "y":
+                                    logger.info("Operation aborted")
+                                    exit()
                             k8s_provider.update()
                 else:
                     logger.debug(
@@ -163,12 +88,13 @@ def ensure_cluster(
                     f"installed on your system"
                 )
                 if do_install:
-                    confirm = input(
-                        f"Do you want to install {cluster_config.provider} on your local system? [y/N] "
-                    )
-                    if confirm.lower() != "y":
-                        logger.info("Operation aborted")
-                        exit()
+                    if not no_input:
+                        confirm = input(
+                            f"Do you want to install {cluster_config.provider} on your local system? [y/N] "
+                        )
+                        if confirm.lower() != "y":
+                            logger.info("Operation aborted")
+                            exit()
                     k8s_provider.install()
         except KeyboardInterrupt:
             print()  # add a newline
@@ -202,8 +128,11 @@ class CMDWrapper(object):
             process.communicate(stdin)
         try:
             if print_output:
-                for stdout_line in iter(process.stdout.readline, ""):
-                    print(stdout_line, end="", flush=True)
+                try:
+                    for stdout_line in iter(process.stdout.readline, ""):
+                        print(stdout_line, end="", flush=True)
+                except Exception as e:
+                    logger.warning(f"Failed to display process output: {str(e)}")
             process.wait()
         except KeyboardInterrupt:
             try:
